pub struct ContextCombinator<Context1: Context, Context2: Context> { /* private fields */ }Trait Implementations
Sourceimpl<Context1: Context, Context2: Context> Context for ContextCombinator<Context1, Context2>
impl<Context1: Context, Context2: Context> Context for ContextCombinator<Context1, Context2>
Sourcefn setup(shared_context: &mut SharedContext) -> Self
fn setup(shared_context: &mut SharedContext) -> Self
Will be executed before the test execution
You should prepare all your test requirement here.
Use the ready to notify that the test can start
Sourcefn teardown(self, shared_context: &mut SharedContext)
fn teardown(self, shared_context: &mut SharedContext)
Will be executed before the test execution even if the test has panicked You should do your clean up here.
fn launch_setup(shared_context: &mut SharedContext) -> Self
fn launch_test<TestFn>( &mut self, test: TestFn, ) -> Result<(), Box<dyn Any + Send>>
fn launch_teardown(self, shared_context: &mut SharedContext)